# Scythe

Scythe is a lightweight tool which helps you seed and reap (scatter and gather)
embarrassingly parallel experiments via the asynchronous distributed queue [Hatchet](https://hatchet.run).

> The project is still in the VERY EARLY stages, and will likely evolve quite a bit in the
> second half of 2025.

- For now, basic documentation can be found in the [README](https://github.com/szvsw/scythe)
- For a look into how a distributed computing stack comes together,
  check out the blog post: [Building Scythe](https://szvsw.github.io/scythe/blog/building-scythe)
- Example usage repository: [szvsw/scythe-example](https://github.com/szvsw/scythe-example)
- Self-hosting Hatchet: [szvsw/hatchet-sst](https://github.com/szvsw/hatchet-sst)
